@@ -1,13 +1,13 @@
 import aerosandbox.numpy as np
 import warnings
-
+from aerosandbox.library.aerodynamics.viscous import Cf_flat_plate
 
 def print_default_warning():
     warnings.warn("Warning: Using a default flat-plate aerodynamics model for this airfoil!\n"
-                  "To use a different one, specify functions in the Airfoil constructor.")
+                  "To use a better, more accurate one, specify functions in the Airfoil constructor.")
 
 
-def default_Cl_function(alpha, Re, mach, deflection):
+def default_CL_function(alpha, Re, mach, deflection):
     """
     Lift coefficient.
     """
@@ -19,12 +19,12 @@ def default_Cl_function(alpha, Re, mach, deflection):
     return Cl
 
 
-def default_Cd_function(alpha, Re, mach, deflection):
+def default_CD_function(alpha, Re, mach, deflection):
     """
     Drag coefficient.
     """
     print_default_warning()
-    Cf = 0.02666 * Re ** -0.139  # Schlichting's model, roughly accounts for laminar part ("Boundary Layer Theory" 7th Ed., pg. 644)
+    Cf = aero.Cf_flat_plate(Re_L = Re)
     Cd_inc = 2 * Cf * (
             1 + (alpha / 5) ** 2
     )
@@ -34,7 +34,7 @@ def default_Cd_function(alpha, Re, mach, deflection):
     return Cd
 
 
-def default_Cm_function(alpha, Re, mach, deflection):
+def default_CM_function(alpha, Re, mach, deflection):
     """
     Pitching moment coefficient, as measured about quarter-chord.
     """
